==> pipewire-docs-1:1.4.9-1-x86_64.pkg.tar.zst: usr/share/doc/pipewire/html/group__pw__impl__node.js <==
var group__pw__impl__node =
[
    [ "impl-node.h", "impl-node_8h.html", null ],
    [ "pw_impl_node_events", "structpw__impl__node__events.html", [
      [ "version", "structpw__impl__node__events.html#a5ec09d921107cfaec7a569d07d7c1430", null ],
      [ "destroy", "structpw__impl__node__events.html#a21b4486448a26b56eea0508a92c99035", null ],
      [ "free", "structpw__impl__node__events.html#a693dbb0bc91e07af02dc409dce738d6a", null ],
      [ "initialized", "structpw__impl__node__events.html#abae73b060850e69368efdace5e1ddd68", null ],
      [ "port_init", "structpw__impl__node__events.html#a347372b746a4f05fc0a6d8ecb1346dd6", null ],
      [ "port_added", "structpw__impl__node__events.html#aaf15bbdebaa2b67dd31ba4c3d56cebc6", null ],
      [ "port_removed", "structpw__impl__node__events.html#a8aa906ff5f65e321b1e500979cd1d748", null ],
      [ "info_changed", "structpw__impl__node__events.html#a9b2f9b0790584b2ee32e0ee46d9e0c5e", null ],
      [ "port_info_changed", "structpw__impl__node__events.html#a8a268deab9a29164fc8f9b57a9ee55e7", null ],
      [ "active_changed", "structpw__impl__node__events.html#a8a7823893c92e2d190c14aa220b71be8", null ],
      [ "state_request", "structpw__impl__node__events.html#a16b71cb7eece2a1b7b2d89007357238b", null ],
      [ "state_changed", "structpw__impl__node__events.html#adbaa329398d27871d25ddacad8a33c12", null ],
      [ "result", "structpw__impl__node__events.html#a5b8cbba5cb1b1d8574929dc73a915463", null ],
      [ "event", "structpw__impl__node__events.html#a912be8dba73d32a813f2a00576384fa3", null ],
      [ "driver_changed", "structpw__impl__node__events.html#ac82d3cde1bc6a6b7a617f80b74c8dc9e", null ],
      [ "peer_added", "structpw__impl__node__events.html#a4364b27231c433313991f473948e5e3f", null ],
      [ "peer_removed", "structpw__impl__node__events.html#a0c45913c502536b96684e02449475a18", null ]
    ] ],
    [ "pw_impl_node_rt_events", "structpw__impl__node__rt__events.html", [
      [ "version", "structpw__impl__node__rt__events.html#af626e58811dda76480d91b4cfc242f71", null ],
      [ "drained", "structpw__impl__node__rt__events.html#aba356d5c2194a4865a6fa46c760f4ccd", null ],
      [ "xrun", "structpw__impl__node__rt__events.html#a2f04aea57fc1da2b792d4925e7fd2918", null ],
      [ "complete", "structpw__impl__node__rt__events.html#ab0476813d8e72d032e97e1c132b875e5", null ],
      [ "incomplete", "structpw__impl__node__rt__events.html#a16607abcb9b54f13c802620e84a523af", null ],
      [ "timeout", "structpw__impl__node__rt__events.html#a35599b05423e0ca196abc06b1c48419d", null ]
    ] ],
    [ "pw_impl_node", "structpw__impl__node.html", null ],
    [ "pw_impl_port", "structpw__impl__port.html", null ],
    [ "PW_VERSION_IMPL_NODE_EVENTS", "group__pw__impl__node.html#ga04abb058294f583c94c63845e520597a", null ],
    [ "PW_VERSION_IMPL_NODE_RT_EVENTS", "group__pw__impl__node.html#gade1c299161466d0b8db700c08938ad3f", null ],
    [ "pw_context_create_node", "group__pw__impl__node.html#ga79ff713f8504019b9ac659a5c513484f", null ],
    [ "pw_impl_node_register", "group__pw__impl__node.html#ga5656d360131166f62339a7171e4277af", null ],
    [ "pw_impl_node_destroy", "group__pw__impl__node.html#gaa4f5ea619bcdb70245eef636caf8d88e", null ],
    [ "pw_impl_node_get_info", "group__pw__impl__node.html#gacfee72740afd2d7af007828232312e87", null ],
    [ "pw_impl_node_get_user_data", "group__pw__impl__node.html#gaf684d5d3e8e1a83e5adc06cd024a31e4", null ],
    [ "pw_impl_node_get_context", "group__pw__impl__node.html#ga68c9ef4b9810849f27568c85fe20ba76", null ],
    [ "pw_impl_node_get_global", "group__pw__impl__node.html#gabf0699ebece66e2973a553b8dcd6ae4b", null ],
    [ "pw_impl_node_get_properties", "group__pw__impl__node.html#gad8ffe77e23e52150a3993eb7383ac7ef", null ],
    [ "pw_impl_node_update_properties", "group__pw__impl__node.html#ga56c6dc7782e72d89afa2816b2b961adf", null ],
    [ "pw_impl_node_set_implementation", "group__pw__impl__node.html#ga2d2a3589827749059c4c13ee0c808043", null ],
    [ "pw_impl_node_get_implementation", "group__pw__impl__node.html#gad3951b4001cf2f3e4179860e02798b0e", null ],
    [ "pw_impl_node_add_listener", "group__pw__impl__node.html#ga2dd3a0b363b4eb2a0fcc52dd43b4af4c", null ],
    [ "pw_impl_node_add_rt_listener", "group__pw__impl__node.html#gaa15ac6102a1e30bfcb3b8b6c4a2fbb2f", null ],
    [ "pw_impl_node_remove_rt_listener", "group__pw__impl__node.html#ga62a51579ecee5cddb693b2896ccead80", null ],
    [ "pw_impl_node_for_each_port", "group__pw__impl__node.html#gaf2dd820815cea83eede3dec8252233f0", null ],
    [ "pw_impl_node_for_each_param", "group__pw__impl__node.html#gaf75985eba1f090ed6a0d5c9097877bd1", null ],
    [ "pw_impl_node_find_port", "group__pw__impl__node.html#ga07267b71d5bbdf5312af836b240b4dab", null ],
    [ "pw_impl_node_get_free_port_id", "group__pw__impl__node.html#gae599f15aede8e3b7b375316035b56fc9", null ],
    [ "pw_impl_node_initialized", "group__pw__impl__node.html#ga10e6a0062b0d54ffd70a6746fd01677a", null ],
    [ "pw_impl_node_set_active", "group__pw__impl__node.html#ga88e0b4faba0ad621a58d451bbb643d70", null ],
    [ "pw_impl_node_is_active", "group__pw__impl__node.html#ga559507dcfa1d49c4ae891b58b336101a", null ],
    [ "pw_impl_node_send_command", "group__pw__impl__node.html#ga42724e8a2f9d9d366892de8d6dc2db6a", null ],
    [ "pw_impl_node_set_param", "group__pw__impl__node.html#gac24ebe417088f6ba836134bdaa314d70", null ]
];

==> pipewire-docs-1:1.6.0-1-x86_64.pkg.tar.zst: usr/share/doc/pipewire/html/group__pw__impl__node.js <==
var group__pw__impl__node =
[
    [ "impl-node.h", "impl-node_8h.html", null ],
    [ "pw_impl_node_events", "structpw__impl__node__events.html", [
      [ "version", "structpw__impl__node__events.html#a5ec09d921107cfaec7a569d07d7c1430", null ],
      [ "destroy", "structpw__impl__node__events.html#a21b4486448a26b56eea0508a92c99035", null ],
      [ "free", "structpw__impl__node__events.html#a693dbb0bc91e07af02dc409dce738d6a", null ],
      [ "initialized", "structpw__impl__node__events.html#abae73b060850e69368efdace5e1ddd68", null ],
      [ "port_init", "structpw__impl__node__events.html#a347372b746a4f05fc0a6d8ecb1346dd6", null ],
      [ "port_added", "structpw__impl__node__events.html#aaf15bbdebaa2b67dd31ba4c3d56cebc6", null ],
      [ "port_removed", "structpw__impl__node__events.html#a8aa906ff5f65e321b1e500979cd1d748", null ],
      [ "info_changed", "structpw__impl__node__events.html#a9b2f9b0790584b2ee32e0ee46d9e0c5e", null ],
      [ "port_info_changed", "structpw__impl__node__events.html#a8a268deab9a29164fc8f9b57a9ee55e7", null ],
      [ "active_changed", "structpw__impl__node__events.html#a8a7823893c92e2d190c14aa220b71be8", null ],
      [ "state_request", "structpw__impl__node__events.html#a16b71cb7eece2a1b7b2d89007357238b", null ],
      [ "state_changed", "structpw__impl__node__events.html#adbaa329398d27871d25ddacad8a33c12", null ],
      [ "result", "structpw__impl__node__events.html#a5b8cbba5cb1b1d8574929dc73a915463", null ],
      [ "event", "structpw__impl__node__events.html#a912be8dba73d32a813f2a00576384fa3", null ],
      [ "driver_changed", "structpw__impl__node__events.html#ac82d3cde1bc6a6b7a617f80b74c8dc9e", null ],
      [ "peer_added", "structpw__impl__node__events.html#a4364b27231c433313991f473948e5e3f", null ],
      [ "peer_removed", "structpw__impl__node__events.html#a0c45913c502536b96684e02449475a18", null ]
    ] ],
    [ "pw_impl_node_rt_events", "structpw__impl__node__rt__events.html", [
      [ "version", "structpw__impl__node__rt__events.html#af626e58811dda76480d91b4cfc242f71", null ],
      [ "drained", "structpw__impl__node__rt__events.html#aba356d5c2194a4865a6fa46c760f4ccd", null ],
      [ "xrun", "structpw__impl__node__rt__events.html#a2f04aea57fc1da2b792d4925e7fd2918", null ],
      [ "complete", "structpw__impl__node__rt__events.html#ab0476813d8e72d032e97e1c132b875e5", null ],
      [ "incomplete", "structpw__impl__node__rt__events.html#a16607abcb9b54f13c802620e84a523af", null ],
      [ "timeout", "structpw__impl__node__rt__events.html#a35599b05423e0ca196abc06b1c48419d", null ]
    ] ],
    [ "pw_impl_node", "structpw__impl__node.html", null ],
    [ "pw_impl_port", "structpw__impl__port.html", null ],
    [ "PW_VERSION_IMPL_NODE_EVENTS", "group__pw__impl__node.html#ga04abb058294f583c94c63845e520597a", null ],
    [ "PW_VERSION_IMPL_NODE_RT_EVENTS", "group__pw__impl__node.html#gade1c299161466d0b8db700c08938ad3f", null ],
    [ "pw_context_create_node", "group__pw__impl__node.html#ga79ff713f8504019b9ac659a5c513484f", null ],
    [ "pw_impl_node_register", "group__pw__impl__node.html#ga5656d360131166f62339a7171e4277af", null ],
    [ "pw_impl_node_destroy", "group__pw__impl__node.html#gaa4f5ea619bcdb70245eef636caf8d88e", null ],
    [ "pw_impl_node_get_info", "group__pw__impl__node.html#gacfee72740afd2d7af007828232312e87", null ],
    [ "pw_impl_node_get_user_data", "group__pw__impl__node.html#gaf684d5d3e8e1a83e5adc06cd024a31e4", null ],
    [ "pw_impl_node_get_context", "group__pw__impl__node.html#ga68c9ef4b9810849f27568c85fe20ba76", null ],
    [ "pw_impl_node_get_global", "group__pw__impl__node.html#gabf0699ebece66e2973a553b8dcd6ae4b", null ],
    [ "pw_impl_node_get_properties", "group__pw__impl__node.html#gad8ffe77e23e52150a3993eb7383ac7ef", null ],
    [ "pw_impl_node_update_properties", "group__pw__impl__node.html#ga56c6dc7782e72d89afa2816b2b961adf", null ],
    [ "pw_impl_node_set_implementation", "group__pw__impl__node.html#ga2d2a3589827749059c4c13ee0c808043", null ],
    [ "pw_impl_node_get_implementation", "group__pw__impl__node.html#gad3951b4001cf2f3e4179860e02798b0e", null ],
    [ "pw_impl_node_add_listener", "group__pw__impl__node.html#ga2dd3a0b363b4eb2a0fcc52dd43b4af4c", null ],
    [ "pw_impl_node_add_rt_listener", "group__pw__impl__node.html#gaa15ac6102a1e30bfcb3b8b6c4a2fbb2f", null ],
    [ "pw_impl_node_remove_rt_listener", "group__pw__impl__node.html#ga62a51579ecee5cddb693b2896ccead80", null ],
    [ "pw_impl_node_for_each_port", "group__pw__impl__node.html#gaf2dd820815cea83eede3dec8252233f0", null ],
    [ "pw_impl_node_for_each_param", "group__pw__impl__node.html#gaf75985eba1f090ed6a0d5c9097877bd1", null ],
    [ "pw_impl_node_find_port", "group__pw__impl__node.html#ga07267b71d5bbdf5312af836b240b4dab", null ],
    [ "pw_impl_node_get_free_port_id", "group__pw__impl__node.html#gae599f15aede8e3b7b375316035b56fc9", null ],
    [ "pw_impl_node_get_free_port", "group__pw__impl__node.html#gacab3a386b7ab0c3e9c1a7c0557d559ed", null ],
    [ "pw_impl_node_initialized", "group__pw__impl__node.html#ga10e6a0062b0d54ffd70a6746fd01677a", null ],
    [ "pw_impl_node_set_active", "group__pw__impl__node.html#ga88e0b4faba0ad621a58d451bbb643d70", null ],
    [ "pw_impl_node_is_active", "group__pw__impl__node.html#ga559507dcfa1d49c4ae891b58b336101a", null ],
    [ "pw_impl_node_send_command", "group__pw__impl__node.html#ga42724e8a2f9d9d366892de8d6dc2db6a", null ],
    [ "pw_impl_node_set_param", "group__pw__impl__node.html#gac24ebe417088f6ba836134bdaa314d70", null ]
];
